## Introduction to Zendure Solarflow Python Library

Welcome to the documentation for the Zendure Solarflow Python Library. This library provides a interface for interacting Zendure Solarflow devices like the Zendure Solarflow HUB 1200/2000, AIO 2400 or Hyper.

## Key Features

- **Device Information Retrieval:** Continously fetch informations from the device.<br>
- **Control of device settings:** Control basic settings like input and output limits or discharge and charge limits.<br>
